package no.inspera.services.pedal;

/**
 * <tt>PEDAL</tt> is interface which holds constants.
 * 
 * @author <a href="mailto:naimdjon@gmail.com">Naimdjon Takhirov</a>
 * @version $Id: PEDAL.java 45069 2008-05-29 08:25:25Z naimdjon $
 * @since 20.12.2007 
 */
public interface PEDAL {

    /**
     * Index enum of fields that are used for in-memory indexing.
     */
    public static enum Index{
        type,
        title,
        id,
        parentId
    }

    /**
     * Learning style enum. Definition of learning styles supported by the system.
     */
    public static enum LearningStyle {
        visual,
        auditory,
        kinesthetic;
        public String s(){return this.toString();}
    }

    /**
     * Level enum. Definition of levels supported by the system.
     */
    public static enum Level {
        low(0,55),
        mid(56,75),
        advanced(76,100);
        private final int lowThreshold; 
        private final int highThreshold;

        /**
         * Constructs a new <tt>Level</tt> enum with the specified low/high thresholds.
         *
         * @param lowThreshold the lower threshold. 
         * @param highThreshold the high threshold.
         */
        Level(int lowThreshold,int highThreshold) {
            this.lowThreshold = lowThreshold;
            this.highThreshold = highThreshold;
        }
        public int lowThreshold(){return this.lowThreshold;}
        public int highThreshold(){return this.highThreshold;}
        
    }

    /**
     * The start page of the course.
     */
    public static final String startPage="/jsp/pedal-ng";

    /**
     * The in-memory index name of the course.
     */
    public static final String indexName="pedal-ng.index";

    /**
     * The session attribute name used to store course information in user's session.
     */
    public static final String course="pedal-ng.course";

    /**
     * The logical id of learning object used as prior knowledge assessment. 
     */
    public static final String prior_knowledge_assessment="pre_assessment";

    /**
     * Identifier marker for currentModuleId. 
     */
    public static final String currentModuleId="pedal-ng.currentModuleId";

    /**
     * Session attribute name for sequencing engine.
     */
    public static final String sequencingEngine="pedal-ng.sequencingEngine";

    /**
     * The learning style metadata element name
     */
    public static final String learningStyle="learning_style";

    /**
     * The level metadata element name
     */
    public static final String level="level";

    /**
     * Session attribute name to store  user's level for different modules.
     */
    public static final String moduleLevels ="moduleLevels";

    /**
     * Default logical id of the course.
     */
    public static  final String defaultLogicalTitle="pedal_ng";

    /**
     * Default marketplace id. This is required by Inspera Content Server.
     */
    public static  final long defaultMarketplaceId=629804;

    /**
     * The file path of the XSL that displays course. The path is absolute to the folder that contains the actual xsl file.
     */
    public final String xslPath=System.getProperty("webapp.path").concat(java.io.File.separator).concat("xsl").concat(java.io.File.separator);
}
