package no.inspera.services.pedal.actions;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

/**
 *
 * Forward result forwards user to some URL.
 *
 * @author <a href="mailto:naimdjon@gmail.com">Naimdjon Takhirov</a>
 * @version $Id: Forward.java 45069 2008-05-29 08:25:25Z naimdjon $
 * @since 15.12.2007
 */
public class Forward implements Result{

    /**
     * Constructs a new Forward object with the url
     * @param url the url to which user is to be forwarded.
     */
    protected Forward(String url){
        this.forwardURL=url;
    }

    /**
     * the forwarding url
     */
    private String forwardURL;

    /**
     * Processes result which causes forwarding user to the url.
     *
     * @param request current request.
     * @param response current reponse.
     * @throws ServletException if any exception occurs when forwarding.
     */
    public void processResult(HttpServletRequest request, HttpServletResponse response)throws ServletException {
        try {
            response.setHeader("Cache-Control","no-cache"); //HTTP 1.1
            response.setHeader("Pragma","no-cache"); //HTTP 1.0
            response.setDateHeader ("Expires", 0); //prevents caching at the proxy server
            if(!response.isCommitted())
            request.getRequestDispatcher(this.forwardURL).forward(request, response);
        } catch (IOException e) {
            e.printStackTrace();
            throw new ServletException(e);
        }
    }

    /**
     * Returns string representation of this object.
     * @return string representation of this object.
     */
    public String toString() {
        return "Forward:"+this.forwardURL;
    }
    
}