package no.inspera.services.pedal.actions;

import javax.servlet.ServletException;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * HTML action simply prints out html to the response.
 *
 * @author <a href="mailto:naimdjon@gmail.com">Naimdjon Takhirov</a>
 * @version $Id: HTML.java 45069 2008-05-29 08:25:25Z naimdjon $
 * @since 23.12.2007
 */
public class HTML implements Result{

    /**
     * HTML result content
     */
    private String html;


    /**
     * Constructs a new HTML object with the specified html content
     * @param html the html content
     */
    protected HTML(String html){
        this.html =html;
    }

    /**
     * Processes result which causes printing an HTML content to the response.
     *
     * @param req current request.
     * @param res current reponse.
     * @throws ServletException if any exception occurs when forwarding.
     */
    public void processResult(HttpServletRequest req, HttpServletResponse res)throws ServletException {
        try {
            res.setHeader("Cache-Control","no-cache"); //HTTP 1.1
            res.setHeader("Pragma","no-cache"); //HTTP 1.0
            res.setDateHeader ("Expires", 0); //prevents caching at the proxy server
            final ServletOutputStream out = res.getOutputStream();
            try {
                out.println(html);
            } finally {
                out.flush();
                out.close();
            }
            
        } catch (java.io.IOException e) {
            e.printStackTrace();
            throw new ServletException(e);
        }
    }

    /**
     * Returns string representation of  this HTML object.
     * @return string representation of the html
     */
    public String toString() {
        return "HTML:"+this.html;
    }

}