package no.inspera.services.pedal.actions;

import no.inspera.db.BaseObjectDataAccess;
import no.inspera.db.MetadataDataAccess;
import no.inspera.services.metadataservice.MetadataTemplate;
import no.inspera.services.pedal.services.RatingService;
import no.inspera.services.rating.Rating;
import no.inspera.utils.Parameters;

/**
 * This action is invoked when the user wants to rate the content.
 *
 * @author <a href="mailto:naimdjon@gmail.com">Naimdjon Takhirov</a>
 * @version $Id: Rate.java 45069 2008-05-29 08:25:25Z naimdjon $
 * @since 03.01.2008
 */
public class Rate implements Action {

    /**
     * Rates the content. The actual rating is done on metadata associated with Learning Object.
     * The result of this action is an empty html if the rating was successful or an error code is sent back to client in case an error occurs. 
     *
     * @param params the current request parameters.
     * @return to the start page of the course.
     */
    public Result execute(Parameters params) {
        try {
            final long objectId = params.getLong("objectId");
            final String logicalName = "metadata_template_for_" + objectId;
            long metadataTemplateId = BaseObjectDataAccess.getInstance().getObjectIdFromLogicalName(logicalName, params.getMarketplaceId());
            if (metadataTemplateId <=1) {
                MetadataTemplate md= new MetadataTemplate();
                md.setMarketplaceId(params.getMarketplaceId());
                md.setLogicalName(logicalName);
                metadataTemplateId=MetadataDataAccess.getInstance().newMetadataTemplate(md,objectId);
            }
            Rating r= new Rating();
            r.setObjectId(metadataTemplateId);
            r.setUserId(params.getUserId());
            r.setScore(params.getInt("score"));
            r.setRatedDate(System.currentTimeMillis());
            RatingService.rate(r);
        } catch (Exception e) {
            e.printStackTrace();
            params.setUserId(-1);
            params.setRequestAttribute("error","Could not configure personalised course");
        }
        return new HTML("<html/>");
    }

}