package no.inspera.services.pedal.actions;

import no.inspera.services.pedal.PEDAL;

import javax.servlet.ServletException;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.stream.StreamSource;
import java.io.FileInputStream;
import java.io.StringReader;

/**
 * The XMLTransform transforms xmls into HTML pages using XSLT.
 *
 * @author <a href="mailto:naimdjon@gmail.com">Naimdjon Takhirov</a>
 * @version $Id: XMLTransform.java 45069 2008-05-29 08:25:25Z naimdjon $
 * @since 16.12.2007 
 */
public class XMLTransform implements Result{

    /**
     * The xml string to be transformed.
     */
    private String xml;

    /**
     * Constructs a new XMLTransform with the specified xml to be transformed.
     * @param xml xml  string to be transformed.
     */
    protected XMLTransform(String xml){
        this.xml=xml;
    }

    /**
     * Processes result which results in actual xml transformation.
     *
     * @param request current request.
     * @param response current reponse.
     * @throws ServletException if any exception occurs when forwarding.
     */
    public void processResult(HttpServletRequest request, HttpServletResponse response)throws ServletException {
        response.setHeader("Cache-Control","no-cache"); //HTTP 1.1
        response.setHeader("Pragma","no-cache"); //HTTP 1.0
        response.setDateHeader ("Expires", 0); //prevents caching at the proxy server
        try {

            final ServletOutputStream out = response.getOutputStream();

            if(request.getRequestURI().indexOf("xml")>-1){
                response.setContentType("text/xml");
                out.write(xml.getBytes());
                out.flush();
                out.close();
                return;
            }

            final String xslFile = PEDAL.xslPath + "Common_Adaptive_CourseDisplay.xsl";
            final StreamSource xslSource = new StreamSource(new FileInputStream(xslFile));
            xslSource.setSystemId(xslFile);
            Transformer tr = TransformerFactory.newInstance().newTemplates(xslSource).newTransformer();
            tr.transform(new StreamSource(new StringReader(xml)), new javax.xml.transform.stream.StreamResult(out));
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * Returns string representation of this object.
     * @return string representation of this object. 
     */
    public String toString() {
        return "XML:"+this.xml;
    }
    
}