package no.inspera.services.pedal.engine;

import no.inspera.services.pedal.Module;

/**
 * A SequencingChain is an object provided by the sequencing engine giving a view into the invocation chain of a sequence request for a module.
 *
 * Sequences use the SequencingChain to invoke the next sequece object  in the chain.
 *
 * @author <a href="mailto:naimdjon@gmail.com">Naimdjon Takhirov</a>
 * @version $Id: Chain.java 45069 2008-05-29 08:25:25Z naimdjon $
 * @since 27.12.2007
 */
public class Chain {

    /**
     * The sequence object
     */
    protected Sequence seq;
    
    /**
     * The next sequence in the chain
     */
    protected Chain next;


    /**
     * Causes the next sequence in the chain to be invoked.
     *
     * @param module the module to pass along the chain
     */
    public void doSequence(Module module){
        if(seq!=null)
            seq.doSequence(next, module);
    }

    /**
     * Returns the string representation of this object. Prints out objects in the sequence chain.
     *
     * @return the string representation of this object.
     */
    public String toString() {
        StringBuffer s=new StringBuffer();
        s.append("seq:").append(seq)
                .append("next:").append(next);
        return s.toString();
    }
}
