package no.inspera.services.pedal.services;

import no.inspera.db.BaseObjectDataAccess;
import no.inspera.db.exception.DataAccessException;
import no.inspera.services.rating.Rating;

import java.sql.Connection;
import java.sql.PreparedStatement;

/**
 *
 * Service class for rating. This class contains methods to rate an object and retrieve a set of ratings related to a specific object or metadata.  
 *
 * @author <a href="mailto:naimdjon@gmail.com">Naimdjon Takhirov</a>
 * @version $Id: RatingService.java 44417 2008-04-21 18:53:36Z naimdjon $
 * @since 23.02.2008 
 */
public class RatingService {

    /**
     * Stores rating to the db. 
     *
     * @param rating the rating object that is to be stored in the database.
     * @throws no.inspera.db.exception.DataAccessException if any data access error occurs.
     */
    public static void rate(Rating rating) throws DataAccessException{
        BaseObjectDataAccess bo=BaseObjectDataAccess.getInstance();
        final Connection con = bo.getConnection();
        PreparedStatement ps= null;
        try {
            int counter=1;
            ps=con.prepareStatement("insert into rating(objectid,userid,rateddate,score) values(?,?,?,?)");
            ps.setLong(counter++,rating.getObjectId());
            ps.setLong(counter++,rating.getUserId());
            ps.setLong(counter++,rating.getRatedDate());
            ps.setInt(counter,rating.getScore());
            final int i = ps.executeUpdate();
            if(i!=1) {
                throw new DataAccessException("Could not insert rating to the database");
            }
        } catch (Exception e){
            e.printStackTrace();
        }finally{
            bo.close(ps);
            bo.close(con);
        }
        
    }
}
